# Scientist AI package

from .knowledge_brain import KnowledgeBrain
from .hypothesis_brain import HypothesisBrain
from .critic_brain import CriticBrain
from .evolution_brain import EvolutionBrain
from .scientific_writer import ScientificWriter
from .proof_engine import ProofEngine
from .literature_review import LiteratureReview
