from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name='agentic-dashboard-ai',
    version='0.1.3',
    description='Autonomous BI dashboard agent for plug-and-play analytics and Power BI integration',
    author='Idriss Bado',
    author_email='your.email@example.com',
    packages=find_packages(where='src') + find_packages(where='scientist_ai'),
    package_dir={'': 'src', 'scientist_ai': 'scientist_ai'},
    install_requires=[
        'pandas',
        'matplotlib',
        'requests',
        'openpyxl',
    ],
    python_requires='>=3.7',
    include_package_data=True,
    url='https://github.com/idrissbado/agentic-ai',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    entry_points={
        'console_scripts': [
            'agentic-dashboard-ai=src.dashboard_agent:main',
        ],
    },
    long_description=long_description,
    long_description_content_type="text/markdown",
)
